==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/ToolActionRadioInfo.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ToolActionInfo } from "./ToolActionInfo";
import { markType } from "./type";
/**
 * @hidden
 */
var ToolActionRadioInfo = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolActionRadioInfo, _super);
    function ToolActionRadioInfo() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._isChecked = false;
        _this._channel = null;
        return _this;
    }
    ToolActionRadioInfo.prototype.get_b = function () {
        return 6;
    };
    Object.defineProperty(ToolActionRadioInfo.prototype, "isChecked", {
        get: function () {
            return this._isChecked;
        },
        set: function (a) {
            this._isChecked = a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ToolActionRadioInfo.prototype, "channel", {
        get: function () {
            return this._channel;
        },
        set: function (a) {
            this._channel = a;
        },
        enumerable: false,
        configurable: true
    });
    ToolActionRadioInfo.$t = markType(ToolActionRadioInfo, 'ToolActionRadioInfo', ToolActionInfo.$);
    return ToolActionRadioInfo;
}(ToolActionInfo));
export { ToolActionRadioInfo };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/ToolActionRadioInfo.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ToolActionInfo } from "./ToolActionInfo";
import { markType } from "./type";
/**
 * @hidden
 */
var ToolActionRadioInfo = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolActionRadioInfo, _super);
    function ToolActionRadioInfo() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._isChecked = false;
        _this._channel = null;
        return _this;
    }
    ToolActionRadioInfo.prototype.get_d = function () {
        return 6;
    };
    Object.defineProperty(ToolActionRadioInfo.prototype, "isChecked", {
        get: function () {
            return this._isChecked;
        },
        set: function (a) {
            this._isChecked = a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ToolActionRadioInfo.prototype, "channel", {
        get: function () {
            return this._channel;
        },
        set: function (a) {
            this._channel = a;
        },
        enumerable: false,
        configurable: true
    });
    ToolActionRadioInfo.$t = markType(ToolActionRadioInfo, 'ToolActionRadioInfo', ToolActionInfo.$);
    return ToolActionRadioInfo;
}(ToolActionInfo));
export { ToolActionRadioInfo };
